==> ejc-zdsmaterialb-impl-3.0.0-20251031.033208-74-sources.jar: com/ejianc/business/zdsmaterial/plan/control/bean/ControlPlanEntity.java <==
package com.ejianc.business.zdsmaterial.plan.control.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 物资总控计划
 *
 * @author generator
 *
 */
 @TableName("ejc_material_control_plan")
public class ControlPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 上级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 上级组织名称
    @TableField(value="engineer_id")
    private Long engineerId; // 主责工程师
    @TableField(value="engineer_name")
    private String engineerName; // 主责工程师名称
    @TableField(value="manager_id")
    private Long managerId; // 项目总工
    @TableField(value="manager_name")
    private String managerName; // 项目总工名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="new_mat_flag")
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName;// 编制者名称
    @TableField(value="project_manager_id")
    private Long projectManagerId; // 项目经理主键
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理名称
    @TableField(value="bill_type")
    private Integer billType; // 单据类型：1-编制，2-变更
    @TableField(value="change_type_id")
    private Long changeTypeId; // 变更原因类型主键
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="material_type_names")
    private String materialTypeNames; // 材料分类
    @TableField(value="has_new_property_val")
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    @TableField(value = "create_user_id")
    private Long createUserId;// 制单人Id

    @TableField(value="exe_org_id")
    private Long exeOrgId; // 执行总部id
    @TableField(value="exe_org_code")
    private String exeOrgCode; // 执行总部编码
    @TableField(value="exe_org_name")
    private String exeOrgName; // 执行总部名称

    @TableField(exist=false)
    @SubEntity(serviceName="controlPlanDetailService",pidName = "planId")
    private List<ControlPlanDetailEntity> detailList = new ArrayList<>(); // 物资总控计划明细

    @TableField(value = "cur_identify_id")
    private String curIdentifyId; //当前物料识别标识

    @TableField(value="budget_ver")
    private String budgetVer; // 管控方式
    @TableField(value = "pack_id")
    private String packId; // 费用包id
    @TableField(value = "pack_code")
    private String packCode; // 费用包code
    @TableField(value = "pack_name")
    private String packName; // 费用包name
    @TableField(value = "material_pack_ids")
    private String materialPackIds; // 物资分类ids

    public String getMaterialPackIds() {
        return materialPackIds;
    }

    public void setMaterialPackIds(String materialPackIds) {
        this.materialPackIds = materialPackIds;
    }

    public String getPackId() {
        return packId;
    }

    public void setPackId(String packId) {
        this.packId = packId;
    }

    public String getPackCode() {
        return packCode;
    }

    public void setPackCode(String packCode) {
        this.packCode = packCode;
    }

    public String getPackName() {
        return packName;
    }

    public void setPackName(String packName) {
        this.packName = packName;
    }

    public String getBudgetVer() {
        return budgetVer;
    }

    public void setBudgetVer(String budgetVer) {
        this.budgetVer = budgetVer;
    }

    public String getCurIdentifyId() {
        return curIdentifyId;
    }

    public void setCurIdentifyId(String curIdentifyId) {
        this.curIdentifyId = curIdentifyId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineerId() {
        return engineerId;
    }

    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }
    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }
    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }

    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }

    public Long getChangeTypeId() {
        return changeTypeId;
    }

    public void setChangeTypeId(Long changeTypeId) {
        this.changeTypeId = changeTypeId;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getMaterialTypeNames() {
        return materialTypeNames;
    }

    public void setMaterialTypeNames(String materialTypeNames) {
        this.materialTypeNames = materialTypeNames;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public Long getExeOrgId() {
        return exeOrgId;
    }

    public void setExeOrgId(Long exeOrgId) {
        this.exeOrgId = exeOrgId;
    }

    public String getExeOrgCode() {
        return exeOrgCode;
    }

    public void setExeOrgCode(String exeOrgCode) {
        this.exeOrgCode = exeOrgCode;
    }

    public String getExeOrgName() {
        return exeOrgName;
    }

    public void setExeOrgName(String exeOrgName) {
        this.exeOrgName = exeOrgName;
    }

    public List<ControlPlanDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<ControlPlanDetailEntity> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-zdsmaterialb-impl-3.0.0-20251205.101103-101-sources.jar: com/ejianc/business/zdsmaterial/plan/control/bean/ControlPlanEntity.java <==
package com.ejianc.business.zdsmaterial.plan.control.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 物资总控计划
 *
 * @author generator
 *
 */
 @TableName("ejc_material_control_plan")
public class ControlPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_name")
    private String billName; // 单据名称
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_code")
    private String orgCode; // 组织编码
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 上级组织编码
    @TableField(value="parent_org_name")
    private String parentOrgName; // 上级组织名称
    @TableField(value="engineer_id")
    private Long engineerId; // 主责工程师
    @TableField(value="engineer_name")
    private String engineerName; // 主责工程师名称
    @TableField(value="manager_id")
    private Long managerId; // 项目总工
    @TableField(value="manager_name")
    private String managerName; // 项目总工名称
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="new_mat_flag")
    private Integer newMatFlag; // 是否有新增材料编码：0-否，1-是
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName;// 编制者名称
    @TableField(value="project_manager_id")
    private Long projectManagerId; // 项目经理主键
    @TableField(value="project_manager_name")
    private String projectManagerName; // 项目经理名称
    @TableField(value="bill_type")
    private Integer billType; // 单据类型：1-编制，2-变更
    @TableField(value="change_type_id")
    private Long changeTypeId; // 变更原因类型主键
    @TableField(value="change_version")
    private Integer changeVersion; // 变更版本
    @TableField(value="material_type_names")
    private String materialTypeNames; // 材料分类
    @TableField(value="has_new_property_val")
    private Integer hasNewPropertyVal; // 是否新增属性值：0-否，1-是
    @TableField(value = "create_user_id")
    private Long createUserId;// 制单人Id

    @TableField(value="exe_org_id")
    private Long exeOrgId; // 执行总部id
    @TableField(value="exe_org_code")
    private String exeOrgCode; // 执行总部编码
    @TableField(value="exe_org_name")
    private String exeOrgName; // 执行总部名称

    @TableField(exist=false)
    @SubEntity(serviceName="controlPlanDetailService",pidName = "planId")
    private List<ControlPlanDetailEntity> detailList = new ArrayList<>(); // 物资总控计划明细

    @TableField(value = "cur_identify_id")
    private String curIdentifyId; //当前物料识别标识

    @TableField(value="budget_ver")
    private String budgetVer; // 管控方式
    @TableField(value = "pack_id")
    private String packId; // 费用包id
    @TableField(value = "pack_code")
    private String packCode; // 费用包code
    @TableField(value = "pack_name")
    private String packName; // 费用包name
    @TableField(value = "material_pack_ids")
    private String materialPackIds; // 物资分类ids

    @TableField(value="costcontrol_id")
    private Long costcontrolId; // 成控组审核工程师ID
    @TableField(value="costcontrol_name")
    private String costcontrolName; // 成控组审核工程师名称

    public String getMaterialPackIds() {
        return materialPackIds;
    }

    public void setMaterialPackIds(String materialPackIds) {
        this.materialPackIds = materialPackIds;
    }

    public String getPackId() {
        return packId;
    }

    public void setPackId(String packId) {
        this.packId = packId;
    }

    public String getPackCode() {
        return packCode;
    }

    public void setPackCode(String packCode) {
        this.packCode = packCode;
    }

    public String getPackName() {
        return packName;
    }

    public void setPackName(String packName) {
        this.packName = packName;
    }

    public String getBudgetVer() {
        return budgetVer;
    }

    public void setBudgetVer(String budgetVer) {
        this.budgetVer = budgetVer;
    }

    public String getCurIdentifyId() {
        return curIdentifyId;
    }

    public void setCurIdentifyId(String curIdentifyId) {
        this.curIdentifyId = curIdentifyId;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getBillName() {
        return billName;
    }

    public void setBillName(String billName) {
        this.billName = billName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineerId() {
        return engineerId;
    }

    public void setEngineerId(Long engineerId) {
        this.engineerId = engineerId;
    }
    public String getEngineerName() {
        return engineerName;
    }

    public void setEngineerName(String engineerName) {
        this.engineerName = engineerName;
    }
    public Long getManagerId() {
        return managerId;
    }

    public void setManagerId(Long managerId) {
        this.managerId = managerId;
    }
    public String getManagerName() {
        return managerName;
    }

    public void setManagerName(String managerName) {
        this.managerName = managerName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getNewMatFlag() {
        return newMatFlag;
    }

    public void setNewMatFlag(Integer newMatFlag) {
        this.newMatFlag = newMatFlag;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Long getProjectManagerId() {
        return projectManagerId;
    }

    public void setProjectManagerId(Long projectManagerId) {
        this.projectManagerId = projectManagerId;
    }

    public String getProjectManagerName() {
        return projectManagerName;
    }

    public void setProjectManagerName(String projectManagerName) {
        this.projectManagerName = projectManagerName;
    }

    public Integer getBillType() {
        return billType;
    }

    public void setBillType(Integer billType) {
        this.billType = billType;
    }

    public Long getChangeTypeId() {
        return changeTypeId;
    }

    public void setChangeTypeId(Long changeTypeId) {
        this.changeTypeId = changeTypeId;
    }

    public Integer getChangeVersion() {
        return changeVersion;
    }

    public void setChangeVersion(Integer changeVersion) {
        this.changeVersion = changeVersion;
    }

    public String getMaterialTypeNames() {
        return materialTypeNames;
    }

    public void setMaterialTypeNames(String materialTypeNames) {
        this.materialTypeNames = materialTypeNames;
    }

    public Integer getHasNewPropertyVal() {
        return hasNewPropertyVal;
    }

    public void setHasNewPropertyVal(Integer hasNewPropertyVal) {
        this.hasNewPropertyVal = hasNewPropertyVal;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public Long getExeOrgId() {
        return exeOrgId;
    }

    public void setExeOrgId(Long exeOrgId) {
        this.exeOrgId = exeOrgId;
    }

    public String getExeOrgCode() {
        return exeOrgCode;
    }

    public void setExeOrgCode(String exeOrgCode) {
        this.exeOrgCode = exeOrgCode;
    }

    public String getExeOrgName() {
        return exeOrgName;
    }

    public void setExeOrgName(String exeOrgName) {
        this.exeOrgName = exeOrgName;
    }

    public List<ControlPlanDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<ControlPlanDetailEntity> detailList) {
        this.detailList = detailList;
    }

    public void setCostcontrolId(Long costcontrolId) {
        this.costcontrolId = costcontrolId;
    }
    public long getCostcontrolId() {
        return costcontrolId;
    }

    public void setControlName(String costcontrolName) {
        this.costcontrolName = costcontrolName;
    }
    public String getControlName() {
        return costcontrolName;
    }
}
